@@ -1,5 +1,5 @@
 use crate::account::{
-    AccountSharedData, InheritableAccountFields, DUMMY_INHERITABLE_ACCOUNT_FIELDS,
+    Account, AccountSharedData, InheritableAccountFields, DUMMY_INHERITABLE_ACCOUNT_FIELDS,
 };
 use crate::clock::INITIAL_RENT_EPOCH;
 
@@ -18,13 +18,13 @@ pub fn create_loadable_account_with_fields(
     name: &str,
     (lamports, rent_epoch): InheritableAccountFields,
 ) -> AccountSharedData {
-    AccountSharedData {
+    AccountSharedData::from(Account {
         lamports,
         owner: id(),
         data: name.as_bytes().to_vec(),
         executable: true,
         rent_epoch,
-    }
+    })
 }
 
 pub fn create_loadable_account_for_test(name: &str) -> AccountSharedData {
